==================================
Review Board 1.6.4.1 Release Notes
==================================

**Release date**: February 28, 2012


Bug Fixes
=========

* Fixed a crash with the Review ID column in the Dashboard when sorting by ID.

  A change to the Review ID column caused a breakage when sorting. An
  invalid database query was generated.

* Fixed validation of the cache backend when saving settings.
  Patch by Bartek Celary.

* Increased the buffer size for memcached stats in order to accommodate larger
  amounts of data. Patch by Bartek Celary.


Contributors
============

* Bartek Celary
* Christian Hammond
